@@ -13,6 +13,7 @@
 #' @param start_field Character string with name of column containing the genes' start positions.
 #' @param stop_field Character string with name of column containing the genes' stop positions.
 #' @param strand_field Character string with name of column containing the genes' strands.
+#'   (The values of the corresponding field can be character strings `"+"` or `"-"`, or numeric +1 or -1.)
 #' @param name_field Character string with name of column containing the genes' names.
 #' @param ... Optional arguments passed to `plot()`.
 #'
@@ -74,7 +75,7 @@ plot_genes <-
 
     # make sure genes are ordered by their start values
     if(any(diff(start) < 0))
-        genes <- genes[order(start, stop),]
+        genes <- genes[order(start, end),]
 
     # grab data
     start <- genes[,start_field]*scale_pos # convert to Mbp
@@ -82,6 +83,10 @@ plot_genes <-
     strand <- as.character(genes[,strand_field])
     name <- as.character(genes[,name_field])
 
+    # deal with +/- 1 for strand
+    strand[!is.na(strand) & (strand=="1" | strand=="+1")] <- "+"
+    strand[!is.na(strand) & strand=="-1"] <- "-"
+
     plot_genes_internal <-
         function(xlab=NULL, xaxs="i",
                  bgcolor="gray92", xat=NULL,
